@@ -95,11 +95,11 @@ enum OCLScopeKind {
 // the corresponding constants from 'std::memory_order' enum.
 enum OCLMemOrderKind {
 #if __cplusplus >= 202002L
-  OCLMO_relaxed = std::memory_order_relaxed,
-  OCLMO_acquire = std::memory_order_acquire,
-  OCLMO_release = std::memory_order_release,
-  OCLMO_acq_rel = std::memory_order_acq_rel,
-  OCLMO_seq_cst = std::memory_order_seq_cst
+  OCLMO_relaxed = static_cast<int>(std::memory_order::relaxed),
+  OCLMO_acquire = static_cast<int>(std::memory_order::acquire),
+  OCLMO_release = static_cast<int>(std::memory_order::release),
+  OCLMO_acq_rel = static_cast<int>(std::memory_order::acq_rel),
+  OCLMO_seq_cst = static_cast<int>(std::memory_order::seq_cst)
 #else
   OCLMO_relaxed = std::memory_order::memory_order_relaxed,
   OCLMO_acquire = std::memory_order::memory_order_acquire,
@@ -239,6 +239,7 @@ const static char AtomicInit[] = "atomic_init";
 const static char AtomicWorkItemFence[] = "atomic_work_item_fence";
 const static char Barrier[] = "barrier";
 const static char Clamp[] = "clamp";
+const static char ClockReadPrefix[] = "clock_read_";
 const static char ConvertPrefix[] = "convert_";
 const static char Dot[] = "dot";
 const static char DotAccSat[] = "dot_acc_sat";
