@@ -224,31 +224,9 @@ void PreprocessMetadataBase::visit(Module *M) {
     if (MDNode *Interface =
             Kernel.getMetadata(kSPIR2MD::IntelFPGAIPInterface)) {
       std::set<std::string> InterfaceStrSet;
-      for (size_t I = 0; I != Interface->getNumOperands(); ++I)
-        InterfaceStrSet.insert(getMDOperandAsString(Interface, I).str());
-
-      // ip_interface metadata will either have Register Map metadata or
-      // Streaming metadata.
-      //
-      // Register Map mode metadata:
-      // Not 'WaitForDoneWrite' mode (to be mapped on '0' literal)
-      // !ip_interface !N
-      // !N = !{!"csr"}
-      // 'WaitForDoneWrite' mode (to be mapped on '1' literal)
-      // !ip_interface !N
-      // !N = !{!"csr", !"wait_for_done_write"}
-      if (InterfaceStrSet.find("csr") != InterfaceStrSet.end()) {
-        int32_t InterfaceMode = 0;
-        if (InterfaceStrSet.find("wait_for_done_write") !=
-            InterfaceStrSet.end())
-          InterfaceMode = 1;
-        EM.addOp()
-            .add(&Kernel)
-            .add(spv::ExecutionModeRegisterMapInterfaceINTEL)
-            .add(InterfaceMode)
-            .done();
-      }
-
+      // Default mode is 'csr' aka !ip_interface !N
+      //                           !N = !{!”csr”}
+      // don't emit any particular SPIR-V for it
       // Streaming mode metadata be like:
       // Not 'stall free' mode (to be mapped on '0' literal)
       // !ip_interface !N
@@ -256,13 +234,15 @@ void PreprocessMetadataBase::visit(Module *M) {
       // 'stall free' mode (to be mapped on '1' literal)
       // !ip_interface !N
       // !N = !{!"streaming", !"stall_free_return"}
+      for (size_t I = 0; I != Interface->getNumOperands(); ++I)
+        InterfaceStrSet.insert(getMDOperandAsString(Interface, I).str());
       if (InterfaceStrSet.find("streaming") != InterfaceStrSet.end()) {
         int32_t InterfaceMode = 0;
         if (InterfaceStrSet.find("stall_free_return") != InterfaceStrSet.end())
           InterfaceMode = 1;
         EM.addOp()
             .add(&Kernel)
-            .add(spv::internal::ExecutionModeStreamingInterfaceINTEL)
+            .add(spv::ExecutionModeStreamingInterfaceINTEL)
             .add(InterfaceMode)
             .done();
       }
@@ -339,16 +319,17 @@ void PreprocessMetadataBase::preprocessVectorComputeMetadata(Module *M,
           FPRoundingModeExecModeMap::map(getFPRoundingMode(Mode));
       spv::ExecutionMode ExecFloatMode =
           FPOperationModeExecModeMap::map(getFPOperationMode(Mode));
-      VCFloatTypeSizeMap::foreach ([&](VCFloatType FloatType,
-                                       unsigned TargetWidth) {
-        EM.addOp().add(&F).add(ExecRoundMode).add(TargetWidth).done();
-        EM.addOp().add(&F).add(ExecFloatMode).add(TargetWidth).done();
-        EM.addOp()
-            .add(&F)
-            .add(FPDenormModeExecModeMap::map(getFPDenormMode(Mode, FloatType)))
-            .add(TargetWidth)
-            .done();
-      });
+      VCFloatTypeSizeMap::foreach (
+          [&](VCFloatType FloatType, unsigned TargetWidth) {
+            EM.addOp().add(&F).add(ExecRoundMode).add(TargetWidth).done();
+            EM.addOp().add(&F).add(ExecFloatMode).add(TargetWidth).done();
+            EM.addOp()
+                .add(&F)
+                .add(FPDenormModeExecModeMap::map(
+                    getFPDenormMode(Mode, FloatType)))
+                .add(TargetWidth)
+                .done();
+          });
     }
     if (Attrs.hasFnAttr(kVCMetadata::VCSLMSize)) {
       SPIRVWord SLMSize = 0;
